translate.lang.af.af

Package translate :: Package lang :: Module af :: Class af |
[hide private]
[frames] | no frames]

# Class af

source code

This class represents Afrikaans.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
capsstart(cls, text) Modify this for the indefinite article ('n). | source code
Inherited from `common.Common`: `alter_length`, `character_iter`, `characters`, `length_difference`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| punctuation = ``u'``.,;:!?-@#$%^*_()[]{}/\'`"<>‘’‛“”„‟′″‴‵‶‷‹›«»…±``...`` We include many types of punctuation here, simply since this is only meant to determine if something is punctuation.
| sentenceend = ``u'``.!?…``'`` These marks can indicate a sentence end.
| sentencere = `re.compile(r'`(?sx)`.`*?``[`\.!\?\u2026`]`\s`+``(?=`\'n\s`[`A`-`Z`...``
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `ignoretests`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `puncdict`, `quotes`, `rtlpunc`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### capsstart(cls, text) Class Method | source code
Modify this for the indefinite article ('n). Overrides: common.Common.capsstart

Class Variable Details | [hide private]

  ### punctuation We include many types of punctuation here, simply since this is only meant to determine if something is punctuation. Hopefully we catch some languages which might not be represented with modules. Most languages won't need to override this. Value:
      u'.,;:!?-@#$%^*_()[]{}/\'`"<>‘’‛“”„‟′″‴‵‶‷‹›«»…±°¹²³·©®×£¥€'

  ### sentencere Value:
      re.compile(r'(?sx).*?[\.!\?\u2026]\s+(?=\'n\s[A-Z]|[^\'a-z\d]|\'[^n])'
      )